.. _api_reference/data-connectors-extension:

Extension hookspec
============================

.. automodule:: sdgx.data_connectors.extension
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
   :private-members:
